<?php
require_once ('wz-zen-util.php');

class ZwSettings
{
	private $options;

	public function __construct()
	{
		add_action('admin_menu', array($this, 'add_plugin_page'));
		add_action('admin_init', array($this, 'page_init'));
	}

	public function add_plugin_page()
	{
		add_options_page(
			__('Widget for Zen Settings', 'widget-for-yandex-zen'),
			__('Widget for Zen', 'widget-for-yandex-zen'),
			'manage_options',
			'zw-settings',
			array($this, 'create_admin_page')
		);
	}

	public function create_admin_page()
	{
		$this->options = get_option('zw_option_name');
		?>
        <div class="wrap">
            <form method="post" action="options.php">
				<?php
				settings_fields('zw_option_group');
				do_settings_sections('zw-settings');
				submit_button();
				?>
            </form>
        </div>
		<?php
	}

	public function page_init()
	{
		register_setting(
			'zw_option_group',
			'zw_option_name',
			array($this, 'sanitize')
		);

		add_settings_section(
			'zw_section_1',
			__('Widget for Zen Settings', 'widget-for-yandex-zen'),
			null,
			'zw-settings'
		);

		add_settings_field(
			'zw_zen_media',
			__('Zen URL', 'widget-for-yandex-zen'),
			array($this, 'zw_zen_media_callback'),
			'zw-settings',
			'zw_section_1'
		);

		add_settings_field(
			'zw_show_logo',
			__('Show Logo', 'widget-for-yandex-zen'),
			array($this, 'zw_show_logo_callback'),
			'zw-settings',
			'zw_section_1'
		);

		add_settings_field(
			'zw_logo_type',
			__('Logo Style', 'widget-for-yandex-zen'),
			array($this, 'zw_logo_type_callback'),
			'zw-settings',
			'zw_section_1'
		);

		add_settings_field(
			'zw_card_style',
			__('Card Style', 'widget-for-yandex-zen'),
			array($this, 'zw_card_style_callback'),
			'zw-settings',
			'zw_section_1'
		);
	}

	function extractPathSegment($url) {
		if (preg_match('#^(id/[a-zA-Z0-9]+|[a-zA-Z0-9_.]+)$#', $url)) {
			return $url;
		}
		if (!preg_match('#^https?://#', $url)) {
			$url = 'http://' . $url;
		}
		$parsedUrl = parse_url($url);
		$host = isset( $parsedUrl['host'] ) ? $parsedUrl['host'] : '';
		$path = isset( $parsedUrl['path'] ) ? $parsedUrl['path'] : '';
		if (!in_array($host, ['dzen.ru', 'zen.yandex.ru'])) {
			return null;
		}
		if (preg_match('#/(id/[a-zA-Z0-9]+|[a-zA-Z0-9_.]+)$#', $path, $matches)) {
			return $matches[1];
		}
		return null;
	}

	public function sanitize($input)
	{
		$new_input = array();

		if (isset($input['zw_zen_media'])) {
			$media = sanitize_text_field($input['zw_zen_media']);

            $media = $this->extractPathSegment($media);

            $new_input['zw_zen_media'] = $media;
		}

		if (isset($input['zw_show_logo'])) {
			$new_input['zw_show_logo'] = $input['zw_show_logo'];
		}

		if (isset($input['zw_logo_type'])) {
			$new_input['zw_logo_type'] = $input['zw_logo_type'];
		}

		if (isset($input['zw_card_style'])) {
			$new_input['zw_card_style'] = sanitize_text_field($input['zw_card_style']);
		}

		delete_option( 'widget_for_zen_data' );

		return $new_input;
	}

	public function zw_zen_media_callback()
	{
		$media = isset($this->options['zw_zen_media']) ? esc_attr($this->options['zw_zen_media']) : '';
		printf('<input type="text" id="zw_zen_media" name="zw_option_name[zw_zen_media]" value="%s" />', $media);
		printf('<br><small>' . __('Enter URL of your Zen Blog.', 'widget-for-yandex-zen') . '<br />');
		if (empty($media)) {
			printf(__('Example: ', 'widget-for-yandex-zen') . ' <code>%s</code>' . '</small>', 'https://dzen.ru/id/5a3def60e86a9e50b401ab4a');
		} else {
			$media_url = 'https://dzen.ru/' . $media;
			printf(__('Current value:', 'widget-for-yandex-zen') . ' <code>%s</code>' . '</small>', $media_url);
		}
	}

	public function zw_show_logo_callback()
	{
		$checked = isset($this->options['zw_show_logo']) ? esc_attr($this->options['zw_show_logo']) : 'always';
		printf('<select name="zw_option_name[zw_show_logo]">');
		printf('<option value="always" %s>' . __('Always', 'widget-for-yandex-zen') . '</option>', selected($checked, "always"));
		printf('<option value="firstonly" %s>' . __('On First Only', 'widget-for-yandex-zen') . '</option>', selected($checked, "firstonly"));
		printf('<option value="never" %s>' . __('Never', 'widget-for-yandex-zen') . '</option>', selected($checked, "never"));
		printf('</select>');
		printf('<br><small>' . __('Choose the way to show Zen logo on the post preview.', 'widget-for-yandex-zen') . '</small>');
	}

	public function zw_logo_type_callback()
	{
		$selected = isset($this->options['zw_logo_type']) ? esc_attr($this->options['zw_logo_type']) : 'dzen_dark_32';
		echo ('<table><tbody valign="middle">');
		printf('<tr><td>%s</td><td>%s</td></tr>', $this->zw_radio_button('dzen_dark_32', $selected), $this->zw_radio_button('dzen_dark_16', $selected));
		printf('<tr><td>%s</td><td>%s</td></tr>', $this->zw_radio_button('dzen_light_32', $selected), $this->zw_radio_button('dzen_light_16', $selected));
		printf('<tr><td>%s</td><td>%s</td></tr>', $this->zw_radio_button('star_32', $selected), $this->zw_radio_button('star_16', $selected));
		/*printf('<tr><td>%s</td><td>%s</td></tr>', $this->zw_radio_button('blue_32', $selected), $this->zw_radio_button('blue_16', $selected));
		printf('<tr><td>%s</td><td>%s</td></tr>', $this->zw_radio_button('red_32', $selected), $this->zw_radio_button('red_16', $selected));
		printf('<tr><td>%s</td><td>%s</td></tr>', $this->zw_radio_button('white_32', $selected), $this->zw_radio_button('white_16', $selected));
		printf('<tr><td>%s</td><td>%s</td></tr>', $this->zw_radio_button('black_32', $selected), $this->zw_radio_button('black_16', $selected));
		printf('<tr><td>%s</td><td>%s</td></tr>', $this->zw_radio_button('broken_32', $selected), $this->zw_radio_button('broken_16', $selected));*/
		echo ('</tbody></table>');
		printf('<br><small>%s</small>', __('Choose the style of the Zen logo.', 'widget-for-yandex-zen'));
	}

	public function zw_card_style_callback()
	{
		$selected_style = isset($this->options['zw_card_style']) ? esc_attr($this->options['zw_card_style']) : 'style-1';
		printf('<select name="zw_option_name[zw_card_style]">');
		printf('<option value="style-1" %s>' . __('Style 1 - 16:9, Caption Below', 'widget-for-yandex-zen') . '</option>', selected($selected_style, "style-1"));
		printf('<option value="style-2" %s>' . __('Style 2 - 4:3, Caption Below', 'widget-for-yandex-zen') . '</option>', selected($selected_style, "style-2"));
		printf('<option value="style-3" %s>' . __('Style 3 - 4:3, Overlay Caption', 'widget-for-yandex-zen') . '</option>', selected($selected_style, "style-3"));
		printf('<option value="style-4" %s>' . __('Style 4 - 16:9, Overlay Caption', 'widget-for-yandex-zen') . '</option>', selected($selected_style, "style-4"));
		printf('</select>');
		printf('<br><small>' . __('Select the display style for the card.', 'widget-for-yandex-zen') . '</small>');
	}

	private function zw_radio_button($logo, $selected)
	{
		$checked = $logo == $selected ? ' checked="checked"' : '';
		return '<input type="radio" name="zw_option_name[zw_logo_type]" id="' . $logo . '" value="' . $logo . '" ' . $checked . '><label for="' . $logo . '"><img src="' . $this->getIcon($logo) . '" /></label><br>';
	}

	public static function getIcon($logoType)
	{
		return plugins_url('/images/zen_logo_' . $logoType . '.png', __FILE__);
	}
}

if (is_admin()) {
	$my_settings_page = new ZwSettings();
}