<?php

/*
Plugin Name: Widget for Zen
Plugin URI: https://wordpress.org/plugins/widget-for-yandex-zen/
Description: This plugin provides Widget for Zen Blogging Platform.
Version: 1.2.10
Author: fromgate
Author URI: https://prozen.ru
License: GPL2
*/

require_once( 'option.php' );
require_once( 'wz-zen-util.php' );

const CACHE_TIME = 1800; // 30 минут

class ZenWidget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'zen_widget',
			esc_html__( 'Zen', 'widget-for-yandex-zen' ),
			array( 'description' => esc_html__( 'Widget for Zen', 'widget-for-yandex-zen' ), )
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @param array $args Widget arguments.
	 * @param array $instance Saved values from database.
	 *
	 * @see WP_Widget::widget()
	 *
	 */
	public function widget( $args, $instance ) {
		echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		echo $this->zen_get( $instance['newscount'] );
		echo $args['after_widget'];
	}

	public function form( $instance ) {
		$title     = ! empty( $instance['title'] ) ? $instance['title'] : '';
		$newscount = ! empty( $instance['newscount'] ) ? $instance['newscount'] : 1;
		if ( $newscount < 1 ) {
			$newscount = 1;
		}
		?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'widget-for-yandex-zen' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text"
                   value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'newscount' ) ); ?>"><?php esc_attr_e( 'News Amount:', 'widget-for-yandex-zen' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'newscount' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'newscount' ) ); ?>" type="number"
                   value="<?php echo esc_attr( $newscount ); ?>">
        </p>

		<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance              = array();
		$instance['title']     = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['newscount'] = ( ! empty( $new_instance['newscount'] ) ) ? strip_tags( $new_instance['newscount'] ) : 1;

		return $instance;
	}

	function zen_get( $newscount ) {
		$opts  = get_option( 'zw_option_name' );
		$media = $opts['zw_zen_media'];

		if ( empty( $media ) ) {
			return esc_html__( 'Channel undefined!', 'widget-for-yandex-zen' );
		}

		$cache = $this->getcache( true );
		if ( ! empty( $cache ) ) {
			return $cache;
		}

		$json_text = WzZenUtil::get_zen_json( $media );
		if ( empty( $json_text ) ) {
			return esc_html__( 'Failed to connect to Zen!', 'widget-for-yandex-zen' );
		}

		$showlogo = $newscount;
		if ( $opts['zw_show_logo'] == 'never' ) {
			$showlogo = 0;
		} elseif ( $opts['zw_show_logo'] == 'firstonly' ) {
			$showlogo = 1;
		}

		$logo = $opts['zw_logo_type'];
		if ( empty( $logo ) ) {
			$showlogo = 0;
		}

		$json  = json_decode( $json_text );
		$count = count( $json->items );
		$div   = '';
		$added = 0;

		for ( $i = 0; $i < $count; $i ++ ) {
			$last  = $json->items[ $i ];
			$title = $last->title;
			$link  = $last->link;

			if ( parse_url( $link, PHP_URL_HOST ) != 'dzen.ru' ) {
				continue;
			}

			$url = $this->clean_zen_url( $link );

			$imgUrl = $last->image;
			if ( empty( $imgUrl ) ) {
				$imgUrl = plugins_url( '/images/zen_empty.png', __FILE__ );
			}

			$style_class = ( isset( $opts['zw_card_style'] ) ? $opts['zw_card_style'] : 'style-4' );

			// Структура HTML для карточки
			$div .= '<div class="dzen-card ' . esc_attr( $style_class ) . '">';
			$div .= '<a href="' . esc_url( $url ) . '" target="_blank">';

			// Начинаем dzen-image
			$div .= '<div class="dzen-image">';
			$div .= '<img src="' . esc_url( $imgUrl ) . '" alt="Zen Image">';

			// Условие для размещения dzen-overlay для стилей 3 и 4 внутри dzen-image
			if ( in_array( $style_class, [ 'style-3', 'style-4' ] ) ) {
				$div .= '<div class="dzen-overlay-inside">';
				if ( $i < $showlogo ) {
					$div .= '<img src="' . esc_url( ZwSettings::getIcon( $logo ) ) . '" class="dzen-logo" alt="Zen Logo">';
				}
				$div .= '<span class="dzen-text">' . esc_html( $title ) . '</span>';
				$div .= '</div>'; // Закрываем dzen-overlay
			}

			$div .= '</div>'; // Закрываем dzen-image

			// Размещение dzen-overlay вне dzen-image для стилей 1 и 2
			if ( in_array( $style_class, [ 'style-1', 'style-2' ] ) ) {
				$div .= '<div class="dzen-overlay-below">';
				if ( $i < $showlogo ) {
					$div .= '<img src="' . esc_url( ZwSettings::getIcon( $logo ) ) . '" class="dzen-logo" alt="Zen Logo">';
				}
				$div .= '<span class="dzen-text">' . esc_html( $title ) . '</span>';
				$div .= '</div>'; // Закрываем dzen-dzen-overlay-below
			}

			$div .= '</a></div>'; // Закрываем ссылку и dzen-card

			$added ++;
			if ( $added >= $newscount ) {
				break;
			}
		}

		$this->savecache( $div );

		return $div;
	}


	function clean_zen_url( $url ) {
		if ( strpos( $url, 'https://yandex.ru/turbo?text=' ) === 0 ) {
			$url = urldecode( str_replace( 'https://yandex.ru/turbo?text=', '', $url ) );
		}
		$url = strtok( $url, '?' );

		return rtrim( $url, '?' );
	}


	function getcache( $check_time ) {
		$data = get_option( 'widget_for_zen_data' );
		if ( $data && ( !$check_time || ( time() - $data['time'] ) < CACHE_TIME ) ) {
			return $data['content'];
		}
		return "";
	}

	function savecache( $data ) {
		if ( !empty( $data ) ) {
			update_option( 'widget_for_zen_data', [
				'content' => $data,
				'time'    => time()
			]);
		} else {
			delete_option( 'widget_for_zen_data' );
		}
	}
}

function register_zen_widget() {
	register_widget( 'ZenWidget' );
}

function register_zen_widget_styles() {
	$plugin_data = get_plugin_data( __FILE__ );
	$plugin_version = $plugin_data['Version'];

	wp_register_style(
		'zenwidgetcss',
		plugins_url( 'css/widget-for-yandex-zen.css', __FILE__ ),
		array(),
		$plugin_version
	);
	wp_enqueue_style( 'zenwidgetcss' );
}

add_action( 'widgets_init', 'register_zen_widget' );
add_action( 'wp_enqueue_scripts', 'register_zen_widget_styles' );